@@ -22,8 +22,8 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 
 '''
-__all__ = ['Config', 'Chdir', 'cmd', 'log','Properties','replace_vars','cmd','ENV','BuildEnv', 'cmd_output','cmd_daemonize']
+__all__ = ['YAMLConfig', 'Chdir', 'cmd', 'log','Properties','replace_vars','cmd','ENV','BuildEnv', 'cmd_output','cmd_daemonize']
 
-from buildtools.config import Config, Properties, replace_vars
+from buildtools.config import YAMLConfig, Properties, replace_vars
 from buildtools.os_utils import Chdir, cmd, ENV, BuildEnv, cmd_daemonize, cmd_output
 from buildtools.bt_logging import log
